@@ -143,7 +143,7 @@ function selectValue(select) {
 */
 function isTag(el, tag) {
 	var re = new RegExp('^(' + tag + ')$', 'i');
-	return re.test(el.tagName);
+	return el && re.test(el.tagName);
 }
 
 /** Get parent node with specified tag name
@@ -491,6 +491,9 @@ function bodyKeydown(event, button) {
 		if (button) {
 			target.form[button].click();
 		} else {
+			if (target.form.onsubmit) {
+				target.form.onsubmit();
+			}
 			target.form.submit();
 		}
 		target.focus();
@@ -540,20 +543,22 @@ function editingKeydown(event) {
 */
 function functionChange() {
 	var input = this.form[this.name.replace(/^function/, 'fields')];
-	if (selectValue(this)) {
-		if (input.origType === undefined) {
-			input.origType = input.type;
-			input.origMaxLength = input.getAttribute('data-maxlength');
-		}
-		input.removeAttribute('data-maxlength');
-		input.type = 'text';
-	} else if (input.origType) {
-		input.type = input.origType;
-		if (input.origMaxLength >= 0) {
-			input.setAttribute('data-maxlength', input.origMaxLength);
+	if (input) { // undefined with the set data type
+		if (selectValue(this)) {
+			if (input.origType === undefined) {
+				input.origType = input.type;
+				input.origMaxLength = input.getAttribute('data-maxlength');
+			}
+			input.removeAttribute('data-maxlength');
+			input.type = 'text';
+		} else if (input.origType) {
+			input.type = input.origType;
+			if (input.origMaxLength >= 0) {
+				input.setAttribute('data-maxlength', input.origMaxLength);
+			}
 		}
+		oninput({target: input});
 	}
-	oninput({target: input});
 	helpClose();
 }
 
@@ -667,6 +672,7 @@ function ajaxForm(form, message, button) {
 		if (window.jush) {
 			jush.highlight_tag(qsa('code', qs('#ajaxstatus')), 0);
 		}
+		messagesPrint(qs('#ajaxstatus'));
 	}, data, message);
 }
 
@@ -702,7 +708,7 @@ function selectClick(event, text, warning) {
 		}
 	};
 	var pos = event.rangeOffset;
-	var value = td.firstChild.alt || td.textContent || td.innerText;
+	var value = (td.firstChild && td.firstChild.alt) || td.textContent || td.innerText;
 	input.style.width = Math.max(td.clientWidth - 14, 20) + 'px'; // 14 = 2 * (td.border + td.padding + input.border)
 	if (text) {
 		var rows = 1;
